# Fireworks AI plugin for LiveKit Agents

Support for speech-to-text api with [Fireworks AI](https://fireworks.ai/).

## Installation

```bash
pip install livekit-plugins-fireworksai
```

## Pre-requisites

You'll need an API key from Fireworks AI. It can be set as an environment variable: `FIREWORKS_API_KEY` 
